﻿using Syncfusion.UI.Xaml.Charts;
using System;
using System.Collections;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using System.Threading.Tasks;
using System.Windows;
using System.Windows.Controls;
using System.Windows.Data;
using System.Windows.Documents;
using System.Windows.Input;
using System.Windows.Media;
using System.Windows.Media.Imaging;
using System.Windows.Navigation;
using System.Windows.Shapes;

namespace SyncfusionOnsdag2
{
    /// <summary>
    /// Interaction logic for MainWindow.xaml
    /// </summary>
    public partial class MainWindow : Window
    {
        public MainWindow()
        {
            InitializeComponent();
        }
    }

    public class SeriesDataTemplateSelector : DataTemplateSelector
    {
        public DataTemplate ColumnSeriesTemplate { get; set; }
        public DataTemplate LineSeriesTemplate { get; set; }
        public override DataTemplate SelectTemplate(object item, DependencyObject container)
        {
            //Check required conditions and return the selected template.

            DataTemplate selectedDataTemplate = null;

            string year = (item as AnnualPriceData).DataType;

            if (year == "Average" || year == "Current")
                selectedDataTemplate = LineSeriesTemplate;
            else
                selectedDataTemplate = ColumnSeriesTemplate;

            return selectedDataTemplate;
        }
    }

    public class SfChartExt : SfChart
    {
        public static readonly DependencyProperty SourceProperty =
            DependencyProperty.Register("Source", typeof(object), typeof(SfChartExt), new PropertyMetadata(null, OnSourceChanged));

        public static readonly DependencyProperty SeriesTemplateProperty =
            DependencyProperty.Register("SeriesTemplate", typeof(DataTemplate), typeof(SfChartExt), new PropertyMetadata(null, OnSeriesTemplateChanged));

        public static readonly DependencyProperty SeriesTemplateSelectorProperty =
          DependencyProperty.Register("SeriesTemplateSelector", typeof(SeriesDataTemplateSelector), typeof(SfChartExt), new PropertyMetadata(null, OnSeriesTemplateChanged));

        //Gets or sets the ItemsSource of collection of collections.
        public object Source
        {
            get { return (object) GetValue(SourceProperty); }
            set { SetValue(SourceProperty, value); }
        }

        //Gets or sets the template for the series to be generated.
        public DataTemplate SeriesTemplate
        {
            get { return (DataTemplate) GetValue(SeriesTemplateProperty); }
            set { SetValue(SeriesTemplateProperty, value); }
        }

        //Get or sets the DataTemplateSelector for the multiple series generation.
        public SeriesDataTemplateSelector SeriesTemplateSelector
        {
            get { return (SeriesDataTemplateSelector) GetValue(SeriesTemplateSelectorProperty); }
            set { SetValue(SeriesTemplateSelectorProperty, value); }
        }

        private static void OnSourceChanged(DependencyObject d, DependencyPropertyChangedEventArgs e)
        {
            (d as SfChartExt).GenerateSeries();
        }

        private static void OnSeriesTemplateChanged(DependencyObject d, DependencyPropertyChangedEventArgs e)
        {
            (d as SfChartExt).GenerateSeries();
        }

        //Generate the series per counts in the itemssource.
        private void GenerateSeries()
        {
            if (Source == null || (SeriesTemplateSelector == null && SeriesTemplate == null)) return;
            var commonItemsSource = (Source as IEnumerable).GetEnumerator();

            List<string> LegendCollection = new List<string>();

            while (commonItemsSource.MoveNext())
            {
                ChartSeries series = null;

                //The conditions checked for setting the SeriesTemplate or SeriesTemplateSelector.
                if (SeriesTemplate != null)
                {
                    series = SeriesTemplate.LoadContent() as ChartSeries;
                }
                else if (SeriesTemplateSelector != null)
                {
                    var selectedseriesTemplate = SeriesTemplateSelector.SelectTemplate(commonItemsSource.Current, null);
                    series = selectedseriesTemplate.LoadContent() as ChartSeries;
                }


                if (LegendCollection.Contains((commonItemsSource.Current as AnnualPriceData).DataType))
                    series.VisibilityOnLegend = Visibility.Collapsed;

                else
                    LegendCollection.Add((commonItemsSource.Current as AnnualPriceData).DataType);


                series.DataContext = commonItemsSource.Current;
                Series.Add(series);
            }
        }
    }


}
